summaryrefslogtreecommitdiff
path: root/innobase/include/log0log.h
diff options
context:
space:
mode:
authormonty@mishka.local <>2004-04-26 15:53:31 +0300
committermonty@mishka.local <>2004-04-26 15:53:31 +0300
commit21fd1d270eb58fa95551bb6e37ecef5a30785929 (patch)
tree25e3315af05fa92d20d2ad1d812882957c400337 /innobase/include/log0log.h
parent7d9a9fd93ac4622d596920169a6d6afbd787c377 (diff)
parent7d3e633edc5db31c0698660ed644d7a18faea41c (diff)
downloadmariadb-git-21fd1d270eb58fa95551bb6e37ecef5a30785929.tar.gz
Merge with 4.0
Diffstat (limited to 'innobase/include/log0log.h')
-rw-r--r--innobase/include/log0log.h4
1 files changed, 1 insertions, 3 deletions
diff --git a/innobase/include/log0log.h b/innobase/include/log0log.h
index 2bdc158502f..4badd2cd7b3 100644
--- a/innobase/include/log0log.h
+++ b/innobase/include/log0log.h
@@ -366,7 +366,6 @@ Writes a buffer to a log file group. */
void
log_group_write_buf(
/*================*/
- ulint type, /* in: LOG_FLUSH or LOG_RECOVER */
log_group_t* group, /* in: log group */
byte* buf, /* in: buffer */
ulint len, /* in: buffer len; must be divisible
@@ -513,8 +512,7 @@ Prints info of the log. */
void
log_print(
/*======*/
- char* buf, /* in/out: buffer where to print */
- char* buf_end);/* in: buffer end */
+ FILE* file); /* in: file where to print */
/**********************************************************
Peeks the current lsn. */